Comment tweaks.
authorCarl Hetherington <cth@carlh.net>
Thu, 8 Apr 2021 00:04:06 +0000 (02:04 +0200)
committerCarl Hetherington <cth@carlh.net>
Thu, 8 Apr 2021 00:04:06 +0000 (02:04 +0200)
src/mxf.h
src/smpte_subtitle_asset.h

index 82c86e8e0c5bc3d7e903bca9cc3206460350379b..19d4a9567b62485ae7585f913f439b645b6c5a5f 100644 (file)
--- a/src/mxf.h
+++ b/src/mxf.h
@@ -140,9 +140,14 @@ protected:
 
        MXF ();
 
+       /** Read an ASDCP::WriterInfo struct, extracting things for our
+        *  member variables.
+        *  @return AssetUUID of the MXF
+        */
        std::string read_writer_info (ASDCP::WriterInfo const &);
-       /** Fill in a ADSCP::WriteInfo struct.
-        *  @param w struct to fill in.
+
+       /** Fill in a ASDCP::WriteInfo struct.
+        *  @param w struct to fill in
         */
        void fill_writer_info (ASDCP::WriterInfo* w, std::string id) const;
 
index 1521bf359e1aca95a7d9c2566594c14a8ba301bf..5d4553a50747d2e15051de16e261174da11be3d4 100644 (file)
@@ -211,10 +211,13 @@ private:
        boost::optional<Time> _start_time;
 
        std::vector<std::shared_ptr<SMPTELoadFontNode>> _load_font_nodes;
/** UUID for the XML inside the MXF, which should be different to the ID of the MXF according to
*  Doremi's 2.8.18 release notes.
         */
        std::string _xml_id;
+
+       /** ResourceID read from the MXF, if there was one */
+       boost::optional<std::string> _resource_id;
 };
@@ -211,10 +211,13 @@ private:
 
        std::vector<std::shared_ptr<SMPTELoadFontNode>> _load_font_nodes;
-       /** UUID for the XML inside the MXF, which should be different to the ID of the MXF according to
-        *  Doremi's 2.8.18 release notes.
+       /** UUID for the XML inside the MXF, which should be the same as the ResourceID in the MXF (our _resource_id)
+        *  but different to the AssetUUID in the MXF (our _id) according to SMPTE Bv2.1 and Doremi's 2.8.18 release notes.
         */
        std::string _xml_id;